@@ -504,12 +504,13 @@ io_watch_stdout (GIOChannel *source, GIOCondition condition, PasswordDialog *pdi
 							  "longer",
 							  "palindrome",
 							  "dictionary",
-							  "simple",
+							  "simpl", /* catches both simple and simplistic */
 							  "similar",
 							  "different",
 							  "case",
 							  "wrapped",
 							  "recovered",
+							  "recent"
 							  "unchanged",
 							  "match",
 							  "1 numeric or special",
@@ -538,7 +539,7 @@ io_watch_stdout (GIOChannel *source, GIOCondition condition, PasswordDialog *pdi
 						   g_strrstr (str->str, "longer") != NULL) {
 						msg = g_strdup (_("The password is too short."));
 					} else if (g_strrstr (str->str, "palindrome") != NULL ||
-						   g_strrstr (str->str, "simple") != NULL ||
+						   g_strrstr (str->str, "simpl") != NULL ||
 						   g_strrstr (str->str, "dictionary") != NULL) {
 						msg = g_strdup (_("The password is too simple."));
 					} else if (g_strrstr (str->str, "similar") != NULL ||
@@ -551,6 +552,8 @@ io_watch_stdout (GIOChannel *source, GIOCondition condition, PasswordDialog *pdi
 					} else if (g_strrstr (str->str, "unchanged") != NULL ||
 						   g_strrstr (str->str, "match") != NULL) {
 						msg = g_strdup (_("The old and new passwords are the same."));
+					} else if (g_strrstr (str->str, "recent") != NULL) {
+						msg = g_strdup (_("The new password has already been used recently."));
 					} else if (g_strrstr (str->str, "failure") != NULL) {
 						/* Authentication failure */
 						msg = g_strdup (_("Your password has been changed since you initially authenticated! Please re-authenticate."));
